@@ -16,8 +16,8 @@ For license and copyright information, see the file COPYRIGHT
    Copyright  : Copyright (C) 2007 John Goerzen
    License    : BSD3
 
-   Maintainer : John Lato <jwlato@gmail.com>
-   Stability  : provisional
+   Maintainer : David Fox <dsf@seereason.com>, Andreas Abel
+   Stability  : stable
    Portability: portable
 
 Generic tools for data structures that can be folded.
@@ -33,7 +33,6 @@ module Data.ListLike.FoldableLL
     ) where
 import Prelude hiding (foldl, foldr, foldr1, sequence_, mapM_, foldMap)
 import qualified Data.Foldable as F
-import Data.Monoid
 import Data.Maybe
 import qualified Data.List as L
 
