@@ -1,18 +1,17 @@
-{-# LANGUAGE CPP
-            ,TypeFamilies
-            ,ScopedTypeVariables
-            ,RankNTypes
-            ,ExistentialQuantification
-            ,MultiParamTypeClasses
-            ,FunctionalDependencies
-            ,FlexibleInstances
-            ,UndecidableInstances
-            ,FlexibleContexts #-}
-{-# OPTIONS -fno-warn-missing-signatures #-}
-
-#if __GLASGOW_HASKELL__ >= 708
+{-# LANGUAGE CPP #-}
 {-# LANGUAGE AllowAmbiguousTypes #-}
-#endif
+{-# LANGUAGE TypeFamilies #-}
+{-# LANGUAGE ScopedTypeVariables #-}
+{-# LANGUAGE RankNTypes #-}
+{-# LANGUAGE ExistentialQuantification #-}
+{-# LANGUAGE MultiParamTypeClasses #-}
+{-# LANGUAGE FunctionalDependencies #-}
+{-# LANGUAGE FlexibleInstances #-}
+{-# LANGUAGE UndecidableInstances #-}
+{-# LANGUAGE FlexibleContexts #-}
+
+{-# OPTIONS -Wno-missing-signatures #-}
+
 
 {-
 Copyright (C) 2007 John Goerzen <jgoerzen@complete.org>
@@ -58,11 +57,15 @@ prop_length f = LL.length f == length (LL.toList f)
 prop_cons f i = llcmp (LL.cons i f) (i : (LL.toList f))
 prop_append f1 f2 = llcmp (LL.append f1 f2) (LL.toList f1 ++ LL.toList f2)
 prop_head f = not (LL.null f) ==> LL.head f == head (LL.toList f)
-  where head (x:xs) = x
+  where
+    head (x:xs) = x
+    head []     = undefined
   -- Andreas Abel, 2023-10-10, issue #32:
   -- Redefine 'head' and 'tail' to avoid the x-partial warning of GHC 9.8.
 prop_tail f = not (LL.null f) ==> llcmp (LL.tail f) (tail (LL.toList f))
-  where tail (x:xs) = xs
+  where
+    tail (x:xs) = xs
+    tail []     = undefined
 prop_init f = not (LL.null f) ==> llcmp (LL.init f) (init (LL.toList f))
 prop_last f = not (LL.null f) ==> LL.last f == last (LL.toList f)
 prop_null f = LL.null f == null (LL.toList f)
